Update of /cvsroot/ufraw/ufraw
In directory vz-cvs-3.sog:/tmp/cvs-serv26509

Modified Files:
        ufraw_routines.c ufraw_settings.cc 
Log Message:
Really fix temperature scale overflow for the OLYMPUS E-PL2 14000K WB preset.

Index: ufraw_settings.cc
===================================================================
RCS file: /cvsroot/ufraw/ufraw/ufraw_settings.cc,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -d -r1.20 -r1.21
--- ufraw_settings.cc   22 Aug 2011 16:30:16 -0000      1.20
+++ ufraw_settings.cc   22 Aug 2011 17:05:17 -0000      1.21
@@ -198,7 +198,7 @@
 class Temperature : public UFNumber
 {
 public:
-    Temperature() : UFNumber(ufTemperature, 2000, 20000, 6500, 0, 50, 200) { }
+    Temperature() : UFNumber(ufTemperature, 2000, 23000, 6500, 0, 50, 200) { }
     void OriginalValueChangedEvent() {
         if (HasParent())
             ParentImage(this).SetWB(uf_manual_wb);

Index: ufraw_routines.c
===================================================================
RCS file: /cvsroot/ufraw/ufraw/ufraw_routines.c,v
retrieving revision 1.114
retrieving revision 1.115
diff -u -d -r1.114 -r1.115
--- ufraw_routines.c    22 Aug 2011 16:30:16 -0000      1.114
+++ ufraw_routines.c    22 Aug 2011 17:05:17 -0000      1.115
@@ -232,7 +232,7 @@
 
 /* Convert between Temperature and RGB.
  * Base on information from http://www.brucelindbloom.com/
  * The fit for D-illuminant between 4000K and 20000K are from CIE
  * The generalization to 2000K < T < 4000K and the blackbody fits
  * are my own and should be taken with a grain of salt.
  */
@@ -279,7 +279,7 @@
 {
     double Tmax, Tmin, testRGB[3];
     Tmin = 2000;
-    Tmax = 20000;
+    Tmax = 23000;
     for (*T = (Tmax + Tmin) / 2; Tmax - Tmin > 0.1; *T = (Tmax + Tmin) / 2) {
         Temperature_to_RGB(*T, testRGB);
         if (testRGB[2] / testRGB[0] > RGB[2] / RGB[0])


------------------------------------------------------------------------------
@@ -232,7 +232,7 @@
 /* Convert between Temperature and RGB.
  * Base on information from http://www.brucelindbloom.com/
- * The fit for D-illuminant between 4000K and 20000K are from CIE
+ * The fit for D-illuminant between 4000K and 23000K are from CIE
  * The generalization to 2000K < T < 4000K and the blackbody fits
  * are my own and should be taken with a grain of salt.
uberSVN's rich system and user administration capabilities and model 
configuration take the hassle out of deploying and managing Subversion and 
the tools developers use with it. Learn more about uberSVN and get a free 
download at:  http://p.sf.net/sfu/wandisco-dev2dev
_______________________________________________
ufraw-cvs mailing list
ufraw-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/ufraw-cvs

Reply via email to